# Part 2: Main program flow

We want to solve a rotational symmetric Laplace problem on a disc and
conduct a grid convergence study against an analytical solution.
The main program flow is implemented in file `main.cc` described below.

The code documentation is structured as follows:

[[_TOC_]]
